@@ -109,7 +109,40 @@ static void sortJsonArray(QJsonArray &array)
     std::transform(l.begin(), l.end(), std::back_inserter(array), [](const auto &s) { return QJsonValue(s); });
 }
 
-static void preProcessCoverage(QJsonObject &obj)
+static QByteArray postProcessJson(const QByteArray &data)
+{
+    // truncate floating point numbers
+    auto s = QString::fromUtf8(data);
+    s = s.replace(QRegularExpression(QStringLiteral(R"((?<=[\[,])(-?\d+.\d{3})\d+(?=[,\]]))")), QStringLiteral("\\1"));
+    return s.toUtf8();
+}
+
+
+class TransportApiMerger
+{
+public:
+    explicit TransportApiMerger(const QString &configPath, const QString &configName);
+    bool applyUpstreamConfig(const QString &apiConfigFile);
+    inline QStringList geometryFiles() const {
+        return m_geometryFiles;
+    }
+
+private:
+    void preProcessConfig(QJsonObject &top);
+    void preProcessCoverage(QJsonObject &obj, const QString &coverageType);
+
+    QString m_configPath;
+    QString m_configName;
+    QStringList m_geometryFiles;
+};
+
+TransportApiMerger::TransportApiMerger(const QString &configPath, const QString &configName)
+    : m_configPath(configPath)
+    , m_configName(configName)
+{
+}
+
+void TransportApiMerger::preProcessCoverage(QJsonObject &obj, const QString &coverageType)
 {
     // sort country codes
     auto regions = obj.take(QLatin1String("region")).toArray();
@@ -150,11 +183,25 @@ static void preProcessCoverage(QJsonObject &obj)
     }
 
     if (!polys.empty()) {
-        obj.insert(QLatin1String("area"), GeoJson::writePolygons(polys));
+        // if the polygon is too complex, store it in an external file loaded on demand
+        if (polys.size() > 1 || polys[0].size() > 10) {
+            const QString geoJsonFile = m_configName + QLatin1Char('_') + coverageType.chopped(8) + QLatin1String(".geojson");
+            QFile f(m_configPath + QLatin1String("/geometry/") + geoJsonFile);
+            if (!f.open(QFile::WriteOnly)) {
+                qCritical() << f.errorString() << f.fileName();
+                return;
+            }
+
+            f.write(postProcessJson(QJsonDocument(GeoJson::writePolygons(polys)).toJson(QJsonDocument::Compact)));
+            obj.insert(QLatin1String("areaFile"), geoJsonFile);
+            m_geometryFiles.push_back(geoJsonFile);
+        } else {
+            obj.insert(QLatin1String("area"), GeoJson::writePolygons(polys));
+        }
     }
 }
 
-static void preProcessConfig(QJsonObject &top)
+void TransportApiMerger::preProcessConfig(QJsonObject &top)
 {
     // move translated keys to the location ki18n expects them
     QJsonObject translatedObj;
@@ -184,7 +231,7 @@ static void preProcessConfig(QJsonObject &top)
     auto coverage = top.take(QLatin1String("coverage")).toObject();
     for (auto it = coverage.begin(); it != coverage.end(); ++it) {
         auto cov = it.value().toObject();
-        preProcessCoverage(cov);
+        preProcessCoverage(cov, it.key());
         it.value() = cov;
     }
     top.insert(QLatin1String("coverage"), coverage);
@@ -198,20 +245,22 @@ static void postProcessConfig(QJsonObject &top)
     if (!langs.empty()) {
         top.insert(QLatin1String("supportedLanguages"), langs);
     }
+
+    // remove inline areas from coverage data
+    auto coverage = top.take(QLatin1String("coverage")).toObject();
+    for (auto it = coverage.begin(); it != coverage.end(); ++it) {
+        auto cov = it.value().toObject();
+        if (cov.contains(QLatin1String("areaFile")) && cov.contains(QLatin1String("area"))) {
+            cov.remove(QLatin1String("area"));
+        }
+        it.value() = cov;
+    }
+    top.insert(QLatin1String("coverage"), coverage);
 }
 
-static QByteArray postProcessJson(const QByteArray &data)
-{
-    // fold arrays of scalar values into one line
-    auto s = QString::fromUtf8(data);
-    s = s.replace(QRegularExpression(QStringLiteral("\\[\n +(\"[A-Za-z-]+\"|[\\d\\.-]+)")), QStringLiteral("[\\1"));
-    s = s.replace(QRegularExpression(QStringLiteral(",\n +(\"[A-Za-z-]+\"|[\\d\\.-]+)(?=[,\n])")), QStringLiteral(", \\1"));
-    s = s.replace(QRegularExpression(QStringLiteral("(?<![,\\]}])\n +](\n|,\n)")), QStringLiteral("]\\1"));
-    return s.toUtf8();
-}
-
-static bool applyUpstreamConfig(const QString &kptConfigFile, const QString &apiConfigFile)
+bool TransportApiMerger::applyUpstreamConfig(const QString &apiConfigFile)
 {
+    const QString kptConfigFile = m_configPath + QLatin1Char('/') + m_configName + QLatin1String(".json");
     qDebug() << "merging" << apiConfigFile << kptConfigFile;
     QFile inFile(apiConfigFile);
     if (!inFile.open(QFile::ReadOnly)) {
@@ -241,10 +290,35 @@ static bool applyUpstreamConfig(const QString &kptConfigFile, const QString &api
         std::cerr << qPrintable(outFile.errorString()) << std::endl;
         return false;
     }
-    outFile.write(postProcessJson(QJsonDocument(outObj).toJson()));
+    outFile.write(QJsonDocument(outObj).toJson());
     return true;
 }
 
+static void writeGeometryQrcFile(const QString &configPath, const QStringList &geometryFiles)
+{
+    QFile f(configPath + QLatin1String("/geometry/geometry.qrc"));
+    if (!f.open(QFile::WriteOnly)) {
+        qCritical() << f.errorString() << f.fileName();
+        return;
+    }
+
+    f.write(R"(<!--
+    SPDX-FileCopyrightText: auto-generated
+    SPDX-License-Identifier: CC0-1.0
+-->
+<RCC>
+    <qresource prefix="/org.kde.kpublictransport/networks/geometry/">
+)");
+    for (const auto &g : geometryFiles) {
+        f.write("        <file>");
+        f.write(g.toUtf8());
+        f.write("</file>\n");
+    }
+    f.write(R"(    </qresource>
+</RCC>
+)");
+}
+
 /** Sync network configurations with upstream transport API repository. */
 int main(int argc, char **argv)
 {
@@ -265,54 +339,6 @@ int main(int argc, char **argv)
         return -1;
     }
 
-    // ### temporary to migrate our format closer to the standard format
-#if 0
-    for (QDirIterator it(parser.value(configPathOpt), QDir::Files); it.hasNext();) {
-        const auto fileName = it.next();
-        QFile f(fileName);
-        if (!f.fileName().endsWith(QLatin1String(".json"))) {
-            continue;
-        }
-        if (!f.open(QFile::ReadOnly)) {
-            qWarning() << "Failed to open" << f.fileName() << f.errorString();
-            continue;
-        }
-
-        const auto doc = QJsonDocument::fromJson(f.readAll());
-        auto topObj = doc.object();
-
-        qDebug() << "Updating" << fileName;
-        auto options = topObj.value(QLatin1String("options")).toObject();
-        auto lineModeMap = options.take(QLatin1String("lineModeMap")).toObject();
-        if (lineModeMap.isEmpty()) {
-            continue;
-        }
-
-        std::vector<QJsonObject> products;
-        for (auto it = lineModeMap.begin(); it != lineModeMap.end(); it++) {
-            QJsonArray bitmasks({ it.key().toInt() });
-            QJsonObject product;
-            product.insert(QLatin1String("bitmasks"), bitmasks);
-            product.insert(QLatin1String("mode"), it.value());
-            products.push_back(std::move(product));
-        }
-        std::sort(products.begin(), products.end(), [](const auto &lhs, const auto &rhs) {
-            return lhs.value(QLatin1String("bitmasks")).toArray().at(0).toInt() < rhs.value(QLatin1String("bitmasks")).toArray().at(0).toInt();
-        });
-
-        QJsonArray productsA;
-        std::copy(products.begin(), products.end(), std::back_inserter(productsA));
-
-        options.insert(QLatin1String("products"), std::move(productsA));
-        topObj.insert(QLatin1String("options"), options);
-
-        f.close();
-        f.open(QFile::WriteOnly | QFile::Truncate);
-        f.write(QJsonDocument(topObj).toJson());
-    }
-#endif
-    // ### end temporary migration code
-
     // match our files and the transport api ones
     struct MatchedConfig {
         QString config;
@@ -379,6 +405,7 @@ int main(int argc, char **argv)
         return lhs.config < rhs.config;
     });
 
+    QStringList geometryFiles;
     for (const auto &c : configs) {
         if (c.apiConfigs.empty()) {
             qDebug() << "  " << c.config << "is missing upstream";
@@ -390,8 +417,13 @@ int main(int argc, char **argv)
             continue;
         }
 
-        if (!applyUpstreamConfig(parser.value(configPathOpt) + QLatin1Char('/') + c.config + QLatin1String(".json"), c.apiConfigs[0])) {
+        TransportApiMerger merger(parser.value(configPathOpt), c.config);
+        if (!merger.applyUpstreamConfig(c.apiConfigs[0])) {
             return -1;
         }
+        geometryFiles.append(merger.geometryFiles());
     }
+
+    std::sort(geometryFiles.begin(), geometryFiles.end());
+    writeGeometryQrcFile(parser.value(configPathOpt), geometryFiles);
 }
